4.48. umbra.ui.visualAccelerators — Umbra 1.0.9 documentation

# 4.48. umbra.ui.visualAccelerators

visualAccelerators.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application visual accelerators objects.

Others:

## 4.48.1. Module Attributes

`umbra.ui.visualAccelerators.` `LOGGER`

## 4.48.2. Functions

`umbra.ui.visualAccelerators.` `highlightCurrentLine`(editor)

  Highlights given editor current line.

  Parameters: | editor (QWidget) – Document editor.
  Returns: | Method success.
  Return type: | bool

`umbra.ui.visualAccelerators.` `highlightOccurences`(editor)

  Highlights given editor current line.

  Parameters: | editor (QWidget) – Document editor.
  Returns: | Method success.
  Return type: | bool

`umbra.ui.visualAccelerators.` `highlightMatchingSymbolsPairs`(editor)

  Highlights given editor matching pairs.

  Parameters: | editor (QWidget) – Document editor.
  Returns: | Method success.
  Return type: | bool